import React, {
    useMemo,
    memo,
    useContext,
    useState,
    useEffect,
    useRef,
} from "https://esm.sh/react";
import ReactDOM from "https://esm.sh/react-dom";

// const MAIN_URL = "https://event.ttshow.tw";

const markData = {
    road: [
        { id: 0 },
        { id: 1 },
        { id: 2 },
        { id: 3 },
        { id: 4 },
        { id: 5 },
        { id: 6 },
    ],
    building: [{ id: "a" }, { id: "b" }, { id: "c" }, { id: "d" }, { id: "e" }],
};

const useScreenSize = () => {
    const [screenWidth, setScreenWidth] = useState(window.innerWidth);
    const [screenHeight, setScreenHeight] = useState(window.innerHeight);

    useEffect(() => {
        window.addEventListener("resize", handleResize);

        return () => {
            window.removeEventListener("resize", handleResize);
        };
    }, []);

    const handleResize = () => {
        setScreenWidth(window.innerWidth);
        setScreenHeight(window.innerHeight);
    };

    return { screenWidth, screenHeight };
};

 const MvListBox = (props) => {
     const { mvList, totalNum, toBt, onOpenSModel } = props;
     const previewBox = (item) => {
         const {
             id,
             number,
             youtube_id,
             songname,
             schoolname,
             description,
             votes,
         } = item;
         return (
             <div
                 className="preview-box border-gray-2 rounded-2xl lg:px-3 lg:py-4 p-2 cursor-pointer"
                 onClick={() => onOpenSModel(id)}
             >
                 <div className="flex-center gap-3 relative">
                     <div
                         className="red-round text-red flex-center pb-12"
                         data-sm="true"
                     >
                         {number}
                     </div>
                     <div className="flex flex-col items-center w-full gap-2 max-w-[80%]">
                         <img
                             className="video ar-v border-gray-2 rounded-lg object-cover"
                             src={`https://i.ytimg.com/vi_webp/${youtube_id}/maxresdefault.webp`}
                         />
                         <div className="lg:pt-2 text-gray max-w-[60%]">
                             <div className="mx-auto single-ellipsis">
                                 {schoolname}
                             </div>
                             <div className="mx-auto single-ellipsis">
                                 {songname}
                             </div>
                         </div>
                     </div>
                     <div className="absolute left-2 bottom-3 text-gray">
                         {votes}票
                     </div>
                 </div>
             </div>
         );
     };

     return (
         <>
             {mvList.map((x) => previewBox(x))}
             {totalNum !== mvList?.length ? (
                 <>
                     {toBt ? (
                         <div className="text-center col-span-1 lg:col-span-3 pt-10 pb-2">
                             下滑看更多作品
                         </div>
                     ) : (
                         <div className="text-center col-span-1 lg:col-span-3 pt-6">
                             loading...
                         </div>
                     )}
                 </>
             ) : (
                 <div className="text-center col-span-1 lg:col-span-3 pt-6">
                     已無更多作品
                 </div>
             )}
         </>
     );
 };

 const Model = (props) => {
     const {
         setOpenModel,
         model,
         buildingVisited,
         setBuildingVisited,
         buildingInit,
         onOpenIdUrl,
         setOneMvData,
         oneMvData,
         getCookie,
         setCookie,
         fbToken,
         setFbToken,
         getOneMv,
     } = props;
     const [openDraw, setOpenModelDraw] = useState(false);
     const drawInputInit = {
         name: "",
         phone: "",
         address: "",
     };
     const [drawInput, setDrawInput] = useState(drawInputInit);
     const [errorMsg, setErrorMsg] = useState(null);
     let isRoad = typeof model === "number";

     const { screenWidth } = useScreenSize();

     const isMobile = screenWidth <= 500;

     const [mvList, setMvList] = useState([]);
     const [searchQ, setSearchQ] = useState("");

     const [toBt, setToBt] = useState(false);
     const [mvPage, setMvPage] = useState(1);
     const [voteLeft, setVoteLeft] = useState(null);
     const [totalNum, setTotalNum] = useState(null);

     const refReadMore = useRef(null);

     const [voteLoading, setVoteLoading] = useState(false);
     const [searchLoading, setSearchLoading] = useState(false);

     // listening to scroll BT

     useEffect(() => {
         if (voteLeft?.left === 0 && voteLeft?.voted === 0) {
             setFbToken("");
         }
     }, [voteLeft]);

     const handleScroll = (ref) => {
         const { scrollHeight, clientHeight, scrollTop } = ref.current;

         if (scrollHeight - clientHeight <= scrollTop + 1) {
             setTimeout(() => {
                 setToBt(true);
             }, 1000);
             setMvPage((pre) => pre + 1);

             getMvList();
         }
     };

     useEffect(() => {
         if (mvPage === 1) return;
         if (toBt) {
             setTimeout(() => {
                 setToBt(false);
             }, 100);
         }
     }, [mvPage]);

     useEffect(() => {
         if (fbToken === "") return;
         getVote();
     }, [fbToken]);

     //  投票截止日期
     const [isVoteDue, setIsVoteDue] = useState(true);
     const handleCountDown = () => {
         const closeDay = new Date("2023-07-28T23:59:59+0800").getTime();
         const nowDay = new Date().getTime();
         setIsVoteDue(!!(nowDay > closeDay));
     };

     useEffect(() => {
         handleCountDown();
     }, []);

     //--- get api ---
     const postData = async () => {
         try {
             const res = await axios({
                 url: routes.infoUrl,
                 method: "post",
                 data: drawInput,
             });
             if (res.data.status === 200) {
                 setDrawInput(drawInputInit);
                 setErrorMsg(null);

                 setOpenModelDraw(false);
                 window.alert("表單送出成功！");
             }
         } catch (err) {
             setErrorMsg(err.response.data.data);
         }
     };
     //  const getMvList = () => {
     //      // TODO fake data
     //      setMvList(fake_data);
     //  };

     //  useEffect(() => {
     //      if (!voteLoading) {
     //       setTimeout(()=>{
     //       setVoteLoading(false);
     //       },10000)
     //      }
     //  }, [voteLoading]);

     const getMvList = async () => {
         const paramsDataQ = {
             q: searchQ,
             page: mvPage,
         };
         try {
             const res = await axios({
                 url: routes.getmvlist,
                 method: "get",
                 params: paramsDataQ,
             });
             if (res.data.status === 200) {
                 let data = res.data.data.data;

                 if (totalNum !== res.data.data.total) {
                     setTotalNum(res.data.data.total);
                 }
                 if (mvPage > 1) {
                     let listArr = mvList;
                     listArr.push(...data);
                     setMvList(listArr);
                 } else {
                     setMvList(data);
                 }
                 setSearchLoading(false);
             }
         } catch (err) {
             console.log(err);
             setSearchLoading(false);
         }
     };

     const getVote = async () => {
         try {
             const res = await axios({
                 url: routes.vote,
                 method: "get",
                 headers: {
                     Authorization: `Bearer ${fbToken}`,
                 },
             });
             if (res.data.status === 200) {
                 let data = res.data.data;
                 setVoteLeft(data);
             }
         } catch (err) {
             console.log(err);
         }
     };

     const postVote = async (id) => {
         const data = { mv_id: id };

         const fdv = new FormData();
         Object.entries(data).map(([key, value]) => fdv.append(key, value));
         try {
             const res = await axios({
                 url: routes.vote,
                 method: "post",
                 data: fdv,
                 headers: {
                     Authorization: `Bearer ${fbToken}`,
                 },
             });
             if (res.data.status === 200) {
                 console.log("投票成功！", res.data.data);
                 getMvList();
                 getOneMv(id);
                 setVoteLeft(res.data.data);
                 setVoteLoading(false);
             }
         } catch (err) {
             console.log(err);
             setVoteLoading(false);

             if (err.response.status === 401) {
                 console.log(401);
                 localStorage.setItem("songid", id);
                 setFbToken("");
             } else if (
                 err.response.data.code === 4030 ||
                 voteLeft?.left === 0
             ) {
                 window.alert("今日投票次數已達上限！");
             } else if (err.response.status === 403) {
                 setIsVoteDue(true);
                 window.alert("投票時間已截止");
             }
         }
     };

     const atSearch = () => {
         setMvPage((pre) => (pre = 1));
         getMvList();
         setSearchLoading(true);
     };
     // for search key "enter"
     const handleKeyDown = (e) => {
         if (e.key === "Enter") {
             e.preventDefault();
             atSearch();
         }
     };

     //  useEffect(() => {
     //      if (searchQ) {
     //          getMvList();
     //      }
     //  }, [mvPage]);

     const onOpenSModel = (id) => {
         // setOpenSongId(id);
         localStorage.setItem("songid", id);
         const singleMv = mvList.find((x) => x.id === id);
         setOneMvData(singleMv);
         setTimeout(() => {
             const stateObj = { id: id };
             history.pushState(
                 stateObj,
                 "",
                 `/2023graduationsongs?songid=${id}`
             );
         });
     };

     const onCloseSModel = () => {
         // setOpenSongId(null);
         setOneMvData(null);
         localStorage.removeItem("songid");
         history.pushState({}, "", "/2023graduationsongs");
     };

     // get Data
     useEffect(() => {
         if (model !== 3) return;
         if (location.href.includes("songid")) {
             onOpenIdUrl();
         }

         // TODO if have time: use memo/get outside of Model
         getMvList();
         getCookie();
     }, [model]);

     // components

     const SingleModel = (props) => {
         const { item } = props;
         const {
             id,
             number,
             youtube_id,
             songname,
             schoolname,
             description,
             votes,
         } = item;

         return (
             <div
                 id="video-section"
                 className="fixed top-0 left-0 right-0 z-50 mb-[80px] p-2 flex items-center justify-center mx-auto lg:my-auto h-[80%] w-[95%] lg:h-[95%] lg:w-auto"
             >
                 <div
                     className="road-border-red border border-red border-4 relative"
                     onClick={(e) => e.stopPropagation()}
                 >
                     <img
                         src="/gs2023/images/scooter.png"
                         alt=""
                         className="absolute right-[-60px] bottom-[-60px] z-40 w-[170px] lg:block hidden h-[170px]"
                     />
                     <div className="overflow-x-hidden lg:mx-auto h-full w-full  flex items-center justify-center">
                         <button
                             className="close-btn"
                             id="close-s-btn"
                             onClick={onCloseSModel}
                         />

                         <div className="px-3 py-4 lg:py-2 mx-auto h-full w-full flex flex-col items-center lg:block lg:relative">
                             <div className="left-box lg:fixed lg:pl-6 lg:pt-1 lg:w-[30%] flex flex-col gap-3 items-center lg:max-w-[350px] pb-6 lg:pb-0">
                                 <div className="title-box flex flex-col gap-2 items-center justify-center z-40">
                                     <div className="red-round text-red flex-center lg:pb-5 lg:py-0 py-8 lg:w-10 w-14 mx-auto lg:text-2xl text-xl">
                                         {number}
                                     </div>
                                     <div className="title-text font-bold lg:text-3xl leading-[1.1] text-center text-2xl">
                                         {schoolname}
                                     </div>
                                     <div className="title-text font-bold lg:text-3xl leading-[1.1] text-center text-2xl">
                                         {songname}
                                     </div>
                                 </div>
                                 <div className="btn-box max-w-[350px] grid grid-cols-[1fr_minmax(120px,_4fr)_1fr] gap-4 items-center justify-center my-3 px-4 relative">
                                     {voteLoading && (
                                         <p className="absolute bottom-[-20px] mx-auto right-0 left-0 text-center">
                                             投票中...
                                         </p>
                                     )}
                                     <img
                                         className="md:w-10 max-w-14 h-auto"
                                         src="/gs2023/images/chara-L.png"
                                         alt=""
                                     />
                                     <input
                                         id="vote-btn"
                                         className="w-full h-auto data-[show=false]:hidden disabled:cursor-not-allowed"
                                         type="image"
                                         src="/gs2023/images/btn-vote.png"
                                         data-show={Boolean(fbToken)}
                                         onClick={() => {
                                             //  if (voteLeft.left <= 0) return;
                                             setVoteLoading(true);
                                             postVote(id);
                                         }}
                                         disabled={
                                             (voteLeft?.left <= 0 &&
                                                 voteLeft?.voted !== 0) ||
                                             voteLoading ||
                                             isVoteDue
                                         }
                                     />
                                     <a
                                         href={routes.sso}
                                         className="w-full h-auto data-[show=false]:hidden disabled:cursor-not-allowed"
                                         data-show={!fbToken}
                                         disabled={isVoteDue}
                                     >
                                         <input
                                             id="login-btn"
                                             type="image"
                                             src="/gs2023/images/btn-login.png"
                                             //  onClick={}
                                             className="w-full h-auto data-[show=false]:hidden disabled:cursor-not-allowed"
                                             data-show={!fbToken}
                                             disabled={isVoteDue}
                                         />
                                     </a>
                                     <img
                                         className="md:w-10 max-w-14 h-auto"
                                         src="/gs2023/images/chara-R.png"
                                         alt=""
                                     />
                                 </div>
                                 {isVoteDue ? (
                                     <div className="text-red text-center pb-3">
                                         投票時間已截止
                                     </div>
                                 ) : !!voteLeft ? (
                                     <div className="text-red text-center pb-3">
                                         你還剩
                                         {parseInt(voteLeft?.left, 10) <= 0
                                             ? 0
                                             : voteLeft?.left}
                                         票
                                     </div>
                                 ) : (
                                     ""
                                 )}
                                 <div className="font-bold text-2xl leading-[1.1] text-center">
                                     {votes} 票
                                 </div>

                                 <div className="share-area my-4 lg:flex gap-3 items-center justify-center border-t-2 border-b-2 border-dashed p-1 hidden">
                                     <span className="font-bold">立刻分享</span>
                                     <input
                                         className="w-10 h-auto"
                                         type="image"
                                         src="/gs2023/images/icon-fb.png"
                                         onClick={() => {
                                             window.open(
                                                 `https://www.facebook.com/sharer/sharer.php?u=${location.href}?utm_source=Facebook&utm_medium=share-icon`,
                                                 "_blank"
                                             );
                                         }}
                                     />
                                     <input
                                         className="w-10 h-auto"
                                         type="image"
                                         src="/gs2023/images/icon-line.png"
                                         onClick={() => {
                                             window.open(
                                                 `https://line.naver.jp/R/msg/text/${location.href}?utm_source=Line&utm_medium=share-icon`,
                                                 "_blank"
                                             );
                                         }}
                                     />
                                 </div>
                             </div>

                             <div className="video-area  place-self-stretch row-span-2 py-4 px-3 flex flex-col gap-3 lg:relative lg:right-0 lg:ml-[40%] z-10">
                                 <div className="video-container flex flex-col items-center relative">
                                     <img
                                         className="iframe absolute top-0 right-0 object-cover"
                                         src={`https://i.ytimg.com/vi_webp/${youtube_id}/maxresdefault.webp`}
                                     ></img>
                                     <iframe
                                         className="iframe"
                                         src={`https://www.youtube.com/embed/${youtube_id}?controls=0`}
                                         title="YouTube video player"
                                         frameborder="0"
                                         allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share"
                                         allowfullscreen
                                     ></iframe>
                                 </div>
                                 <div className="border-gray-2 w-full rounded py-4 px-6 box-border whitespace-pre-line leading-relaxed">
                                     {description}
                                 </div>
                             </div>

                             <div className="share-area my-4 flex gap-3 items-center justify-center border-t-2 border-b-2 border-dashed  p-1 lg:hidden block">
                                 <span className="font-bold">立刻分享</span>
                                 <input
                                     className="w-10 h-auto"
                                     type="image"
                                     src="/gs2023/images/icon-fb.png"
                                     onClick={() => {
                                         window.open(
                                             `https://www.facebook.com/sharer/sharer.php?u=${location.href}?utm_source=Facebook&utm_medium=share-icon`,
                                             "_blank"
                                         );
                                     }}
                                 />

                                 <input
                                     className="w-10 h-auto"
                                     type="image"
                                     src="/gs2023/images/icon-line.png"
                                     onClick={() => {
                                         window.open(
                                             `https://line.naver.jp/R/msg/text/${location.href}?utm_source=Line&utm_medium=share-icon`,
                                             "_blank"
                                         );
                                     }}
                                 />
                             </div>
                         </div>
                     </div>
                 </div>
             </div>
         );
     };

     const content =
         model === 0 ? (
             <div className="flex flex-col items-center gap-6 md:m-[2.5rem] m-4 md:px-10">
                 {openDraw ? (
                     <div className="flex flex-col items-center gap-6 w-full">
                         <img
                             src="/gs2023/images/model/m-title-0-1.png"
                             alt=""
                             className="md:w-[400px] w-full"
                         />
                         <div className="bg-gray rounded-3xl px-4 py-5 md:py-6 text-white flex flex-col md:gap-6 gap-3">
                             <div className="flex">
                                 <div className="w-[70px]">姓名：</div>
                                 <input
                                     type="text"
                                     className="w-full bg-gray text-white outline-none border-b-2 border-white"
                                     onChange={(e) =>
                                         setDrawInput({
                                             ...drawInput,
                                             name: e.target.value,
                                         })
                                     }
                                     value={drawInput.name}
                                 />
                             </div>
                             <div className="flex">
                                 <div className="w-[70px]">電話：</div>
                                 <input
                                     type="text"
                                     className="w-full bg-gray text-white outline-none border-b-2 border-white"
                                     onChange={(e) =>
                                         setDrawInput({
                                             ...drawInput,
                                             phone: e.target.value,
                                         })
                                     }
                                     value={drawInput.phone}
                                 />
                             </div>
                             <div className="flex">
                                 <div className="w-[70px]">地址：</div>
                                 <input
                                     type="text"
                                     className="w-full bg-gray text-white outline-none border-b-2 border-white"
                                     onChange={(e) =>
                                         setDrawInput({
                                             ...drawInput,
                                             address: e.target.value,
                                         })
                                     }
                                     value={drawInput.address}
                                 />
                             </div>
                         </div>
                         {errorMsg !== [] && errorMsg !== null && (
                             <>
                                 <div className="text-brightRed">
                                     {errorMsg.name}
                                 </div>
                                 <div className="text-brightRed">
                                     {errorMsg.phone}
                                 </div>
                                 <div className="text-brightRed">
                                     {errorMsg.address}
                                 </div>
                             </>
                         )}
                         <button
                             onClick={() => {
                                 postData();
                                 setBuildingVisited(buildingInit);
                             }}
                         >
                             <img
                                 src="/gs2023/images/model/btn-send.png"
                                 alt=""
                                 className="w-[160px] send-btn "
                             />
                         </button>
                         <div className="text-box border-red border-2 bg-white w-full h-full md:p-4 p-0 m-2  rounded-xl ">
                             {data_drawing(isMobile)}
                         </div>
                     </div>
                 ) : (
                     <>
                         <div className="flex flex-wrap md:flex-nowrap justify-center">
                             {markData.building.map((buildingItem) => {
                                 const bName = `b-icon-${
                                     buildingItem.id +
                                     (buildingVisited[buildingItem.id]
                                         ? ""
                                         : "-bw")
                                 }`;
                                 return (
                                     <img
                                         src={`/gs2023/images/model/${bName}.png`}
                                         className="model-img"
                                         alt=""
                                     />
                                 );
                             })}
                         </div>

                         <button
                             onClick={() => {
                                 setOpenModelDraw(true);
                             }}
                             disabled={
                                 !(
                                     Object.values(buildingVisited).findIndex(
                                         (x) => x === false
                                     ) === -1
                                 )
                             }
                         >
                             <img
                                 src="/gs2023/images/model/btn-drawing.png"
                                 alt=""
                                 className="w-[160px] drawing-btn data-[active=false]:hidden"
                                 data-active={
                                     Object.values(buildingVisited).findIndex(
                                         (x) => x === false
                                     ) === -1
                                 }
                             />
                             <img
                                 src="/gs2023/images/model/btn-drawing-bw.png"
                                 alt=""
                                 className="w-[160px] drawing-btn-no data-[active=false]:hidden "
                                 data-active={
                                     !(
                                         Object.values(
                                             buildingVisited
                                         ).findIndex((x) => x === false) === -1
                                     )
                                 }
                             />
                         </button>
                         <div className="text-box border-red border-2 bg-white w-full h-full md:p-4 p-1 rounded-xl">
                             {data_drawing(isMobile)}
                         </div>
                     </>
                 )}
             </div>
         ) : model === 1 ? (
             <div className="md:max-w-[600px] mx-auto md:mt-24 ">
                 <p className="border-b-2 border-dashed pb-8 whitespace-pre-wrap leading-12 md:pl-[28px] md:m-0 mr-4 ml-5">
                     {isMobile ? (
                         <>
                             {`又來到畢業的季節，各位學生們將踏上人生的下個階段，繼續勇敢追夢，探索屬於你的城市風景！\n
快來報名屬於自己青春的畢業歌，讓我們一起逗陣來Song吧！\n
上傳屬於你們的畢業歌，最大獎`}
                             <span className="text-brightRed text-[1.5rem] underline mx-1 md:text-[1.875rem] ">
                                 五萬元
                             </span>
                             等你拿！
                         </>
                     ) : (
                         <>
                             {`又來到畢業的季節，各位學生們將踏上人生的下個階段，\n
繼續勇敢追夢，探索屬於你的城市風景！\n
快來報名屬於自己青春的畢業歌，讓我們一起逗陣來Song吧！\n
上傳屬於你們的畢業歌，最大獎`}
                             <span className="text-brightRed text-[1.5rem] underline mx-1 md:text-[1.875rem] ">
                                 五萬元
                             </span>
                             等你拿！
                         </>
                     )}
                 </p>
                 <div className="flex flex-col md:flex-row gap-2 items-center p-6 md:p-0 md:mt-6 md:pl-[28px]">
                     {isMobile ? (
                         <>
                             <img
                                 src={`/gs2023/images/model/m-1-1_mb.png`}
                                 className="max-w-[120px] md:max-w-[200px]"
                                 alt=""
                             />
                             <img
                                 src={`/gs2023/images/model/m-1-2_mb.png`}
                                 className="max-w-[120px] md:max-w-[200px]"
                                 alt=""
                             />
                             <img
                                 src={`/gs2023/images/model/m-1-3_mb.png`}
                                 className="max-w-[120px] md:max-w-[200px]"
                                 alt=""
                             />
                         </>
                     ) : (
                         <img
                             src="/gs2023/images/model/m-1-1.png"
                             className="w-full pr-[28px]"
                             alt=""
                         />
                     )}
                 </div>
             </div>
         ) : model === 2 ? (
             <>
                 <div className="grid grid-cols-2 md:grid-cols-4 gap-2 w-full md:gap-4 md:py-10 md:px-10 px-4">
                     <img
                         src="/gs2023/images/model/m-2-1.png"
                         className="max-w-[120px] md:max-w-[220px] justify-self-center"
                         alt=""
                     />
                     <img
                         src="/gs2023/images/model/m-2-2.png"
                         className="max-w-[120px] md:max-w-[220px] justify-self-center"
                         alt=""
                     />
                     <img
                         src="/gs2023/images/model/m-2-3.png"
                         className="max-w-[120px] md:max-w-[220px] justify-self-center"
                         alt=""
                     />
                     <img
                         src="/gs2023/images/model/m-2-4.png"
                         className="max-w-[120px] md:max-w-[220px] justify-self-center"
                         alt=""
                     />
                 </div>

                 <div className="border-red border-2 p-4 m-2 rounded-xl pt-16 relative bg-white md:w-[85%] md:mx-auto mt-20 md:mt-16 mx-4 md:px-10 whitespace-pre-wrap leading-10 md:pt-[80px]">
                     <img
                         src={`/gs2023/images/model/m-title-2-a.png`}
                         className="model-title absolute right-0 left-0  top-[-35px] "
                         alt=""
                         data-road={true}
                     />
                     {data_signUpCompetitions}
                 </div>
             </>
         ) : model === 3 ? (
             <div className="relative lg:m-8 m-6">
                 <div className="search lg:absolute relative lg:top-[-80px] lg:bottom-auto bottom-[18px] lg:right-0 border-gray-2 px-3 py-2 rounded-full flex gap-3">
                     <input
                         type="image"
                         src="gs2023/images/icon-search.png"
                         className="h-6 w-auto"
                         alt="search-btn"
                         onClick={() => atSearch()}
                     />
                     <input
                         type="text"
                         placeholder="搜尋編號 / 校名 / 歌名"
                         className="focus:outline-none placeholder-gray w-full"
                         value={searchQ}
                         onChange={(e) => setSearchQ(e.target.value)}
                         onKeyDown={(e) => handleKeyDown(e)}
                     />
                 </div>
                 <div className="grid grid-cols-1 lg:grid-cols-3 lg:gap-4 gap-2">
                     {searchLoading && (
                         <div className="text-center lg:col-span-3 pt-4">
                             搜尋中...
                         </div>
                     )}
                     {mvList?.length > 0 ? (
                         <MvListBox
                             mvList={mvList}
                             totalNum={totalNum}
                             toBt={toBt}
                             onOpenSModel={onOpenSModel}
                         />
                     ) : searchQ.length > 0 ? (
                         <div className="text-center lg:col-span-3 pt-10">
                             找不到相關參賽者，請換個關鍵字再試試
                         </div>
                     ) : (
                         <div className="loader">loading...</div>
                     )}
                 </div>
             </div>
         ) : model === 4 ? (
             <div className="flex flex-col items-center lg:gap-10 gap-5 m-4 mb-6 lg:mt-[60px] lg:mx-20 relative">
                 <img
                     src="/gs2023/images/model/gr-people-L.png"
                     className="absolute left-[-2rem] top-[15%] hidden lg:block w-[18%]"
                 />
                 <img
                     src="/gs2023/images/model/gr-people-R.png"
                     className="absolute right-[-1rem] top-[-4.5rem] hidden md:block w-[18%]"
                 />
                 <img
                     src={`/gs2023/images/model/m-4-1${
                         isMobile ? "_mb" : ""
                     }.png`}
                     className="md:w-[50%] w-[85%] mx-auto"
                     alt=""
                 />
                 <img
                     src={`/gs2023/images/model/m-4-2${
                         isMobile ? "_mb" : ""
                     }.png`}
                     className="md:w-[64%] w-[85%] mx-auto"
                     alt=""
                 />
                 <img
                     src={`/gs2023/images/model/m-4-3${
                         isMobile ? "_mb" : ""
                     }.png`}
                     className="md:w-[64%] w-[85%] mx-auto"
                     alt=""
                 />
             </div>
         ) : model === 5 ? (
             <div className="flex flex-col gap-4 md:gap-10 items-center justify-center mx-4 md:mt-[6rem] md:mx-16 mt-4">
                 <div className="flex flex-col gap-4 md:flex-row w-full items-center justify-center">
                     <img
                         src={`/gs2023/images/model/m-5-1${
                             isMobile ? "_mb" : ""
                         }.png`}
                         className="md:w-[34%]"
                         alt=""
                     />
                     <img
                         src={`/gs2023/images/model/m-5-2${
                             isMobile ? "_mb" : ""
                         }.png`}
                         className="md:w-[34%]"
                         alt=""
                     />
                     <img
                         src={`/gs2023/images/model/m-5-3${
                             isMobile ? "_mb" : ""
                         }.png`}
                         className="md:w-[34%]"
                         alt=""
                     />
                 </div>
                 <div className="flex flex-col md:flex-row w-full gap-4 items-center justify-center ">
                     <img
                         src="/gs2023/images/model/m-5-4.png"
                         className="md:w-[34%] md:mt-0 mt-2"
                         alt=""
                     />
                     <img
                         src="/gs2023/images/model/m-5-5.png"
                         className="md:w-[34%] md:mt-0 mt-2"
                         alt=""
                     />
                 </div>
             </div>
         ) : model === 6 ? (
             <div className="flex flex-col justify-center items-center md:flex-row gap-16 md:gap-2 mx-4 my-10 md:mt-[70px] md:mx-4">
                 <img
                     src={`/gs2023/images/model/m-6-1${
                         isMobile ? "_mb" : ""
                     }.png`}
                     className="w-full md:w-[30%]"
                     alt=""
                 />
                 <img
                     src={`/gs2023/images/model/m-6-2${
                         isMobile ? "_mb" : ""
                     }.png`}
                     className="w-full md:w-[30%]"
                     alt=""
                 />
                 <img
                     src={`/gs2023/images/model/m-6-3${
                         isMobile ? "_mb" : ""
                     }.png`}
                     className="w-full md:w-[30%]"
                     alt=""
                 />
             </div>
         ) : !isRoad ? (
             <div className="flex flex-col items-center gap-8 mx-4 my-10 md:max-w-[600px] md:mx-auto">
                 <img
                     src={`/gs2023/images/model/m-subtitle-${model}.png`}
                     alt={data_shop[model].title}
                     className={
                         model === "b"
                             ? "px-4 md:pl-5 md:max-h-[140px] object-contain"
                             : "h-[30px] md:h-[40px] md:pl-5 px-2 object-contain"
                     }
                 />

                 {model === "b" && (
                     <img
                         className="cursor-pointer"
                         src="/gs2023/images/model/m-b-img.png"
                         onClick={() => {
                             window.open(data_shop[model].imgUrl, "_blank");
                         }}
                         alt=""
                     />
                 )}
                 <div className="text-box border-red border-2 bg-white w-full h-full p-4 m-2 rounded-xl whitespace-pre-wrap font-bold md:text-[1.25rem] md:px-10 leading-[2rem]">
                     {model === "b" && isMobile ? (
                         <>
                             <div className="pb-2">
                                 YAMAHA CYGNUS GRYPHUS
                                 擁有先進的電控系統，提升騎乘者的安全感！
                             </div>
                             <div className="pb-2">
                                 TCS 循跡控制系統可防止打滑，更配合 ABS
                                 防鎖死煞車系統，提升駕馭潛力！智慧型 Smart Key
                                 免鑰匙不只方便，還有尋車功能，根本太貼心了拉～最適合找不到車的你！
                             </div>
                             <div>
                                 另外還有全彩液晶顯示儀表板，來電和訊息不漏接。這款車不只擁有前衛科技元素設計，展現精準視覺效果，提供大家更安全、便利的騎乘體驗。
                             </div>
                         </>
                     ) : (
                         data_shop[model].content
                     )}
                 </div>
                 <div className="flex gap-6 justify-between max-w-[300px]">
                     {model === "a" || model === "e" ? (
                         <>
                             <button
                                 onClick={() => {
                                     window.open(
                                         data_shop[model].url,
                                         "_blank"
                                     );
                                 }}
                             >
                                 <img
                                     src="/gs2023/images/model/btn-read-more.png"
                                     alt=""
                                 />
                             </button>
                             <button
                                 onClick={() => {
                                     if (model === "e" && !isMobile) {
                                         window.alert("請使用手機開啟連結");
                                     } else {
                                         window.open(
                                             data_shop[model].imgUrl,
                                             "_blank"
                                         );
                                     }
                                 }}
                             >
                                 <img
                                     src={`/gs2023/images/model/${
                                         model === "a"
                                             ? "btn-shop"
                                             : "btn-get-more"
                                     }.png`}
                                     alt=""
                                 />
                             </button>
                         </>
                     ) : (
                         <button
                             className="mx-16"
                             onClick={() => {
                                 window.open(data_shop[model].url, "_blank");
                             }}
                         >
                             <img
                                 src="/gs2023/images/model/btn-read-more.png"
                                 alt=""
                             />
                         </button>
                     )}
                 </div>
                 {model === "e" && (
                     <div className="flex justify-center flex-col items-center">
                         <p className="leading-[30px] pb-6">
                             step1：先下載大苑子成為數位會員
                             <br />
                             step2：點選連結，領取專屬優惠券
                         </p>
                         <img
                             src="/gs2023/images/model/m-e-coupon.jpg"
                             className="cursor-pointer"
                             onClick={() => {
                                 if (!isMobile) {
                                     window.alert("請使用手機開啟連結");
                                 } else {
                                     window.open(
                                         data_shop[model].imgUrl,
                                         "_blank"
                                     );
                                 }
                             }}
                         />
                     </div>
                 )}
                 {/* yamaha 以外圖片 */}
                 {model !== "b" && (
                     <img
                         src={`/gs2023/images/model/m-${model}-img.png`}
                         className={
                             "cursor-pointer" +
                             (model === "e" ? "max-w-[400px]" : "")
                         }
                         onClick={() => {
                             if (model === "e") {
                                 window.open(data_shop[model].url, "_blank");
                             } else {
                                 window.open(data_shop[model].imgUrl, "_blank");
                             }
                         }}
                         alt=""
                     />
                 )}
             </div>
         ) : (
             ""
         );

     return (
         <div
             className="darken-bg fixed pointer md:z-50 z-60"
             onClick={() => {
                 if (!!oneMvData && model === 3) {
                     onCloseSModel();
                 } else {
                     setOpenModel(false);
                 }
             }}
         >
             {model === 3 ? (
                 <>
                     {!!oneMvData && (
                         <div
                             className="vote-section mb-[80px] p-2 flex items-center justify-center top-0 right-0 left-0 mx-auto md:my-auto rounded-lg relative h-[80%] w-[95%] md:h-[95%] md:w-full data-[show=false]:hidden"
                             data-show={!!oneMvData}
                         >
                             <div className="z-10 relative">
                                 <SingleModel item={oneMvData} />
                             </div>
                         </div>
                     )}

                     <div
                         className="vote-section z-40 mb-[80px] p-2 flex items-center justify-center top-0 right-0 left-0 mx-auto lg:my-auto rounded-lg relative lg:z-50 z-60 h-[80%] lg:h-[90%] w-[95%] lg:w-auto data-[show=false]:hidden"
                         data-show={!!!oneMvData}
                     >
                         <img
                             src="/gs2023/images/scooter.png"
                             alt=""
                             className="absolute right-[-20px] bottom-0 z-40 w-[170px] lg:block hidden h-[170px]"
                         />
                         <div
                             className="road-border-2 flex flex-col gap-6"
                             onClick={(e) => e.stopPropagation()}
                         >
                             <div
                                 ref={refReadMore}
                                 className="overflow-y-auto overflow-x-hidden lg:mx-auto h-full w-full"
                                 onScroll={() => handleScroll(refReadMore)}
                                 onfocus={() => handleScroll(refReadMore)}
                             >
                                 <button
                                     className="close-btn"
                                     onClick={() => setOpenModel(false)}
                                 ></button>
                                 <img
                                     src={`/gs2023/images/model/m-title-${model}.png`}
                                     className="model-title"
                                     alt=""
                                     data-road={isRoad}
                                 />
                                 <div className="mx-auto">{content}</div>
                             </div>
                         </div>
                     </div>
                 </>
             ) : (
                 <div className="z-40 mb-[80px] p-2 mx-6 flex items-center justify-center top-0 right-0 left-0 mx-auto md:my-auto rounded-lg relative md:z-50 z-60 h-[80%] w-[95%] md:h-[95%] md:w-auto">
                     <img
                         src="/gs2023/images/scooter.png"
                         alt=""
                         className="absolute right-[-100px] bottom-0 z-40 w-[170px] md:block hidden h-[170px]"
                     />
                     <div
                         className="road-border flex flex-col gap-6 "
                         onClick={(e) => e.stopPropagation()}
                     >
                         <div className="overflow-y-auto overflow-x-hidden md:mx-auto h-full w-full ">
                             <button
                                 className="close-btn"
                                 onClick={() => setOpenModel(false)}
                             ></button>
                             <img
                                 src={`/gs2023/images/model/m-title-${model}.png`}
                                 className="model-title"
                                 alt=""
                                 data-road={isRoad}
                             />
                             <div className="mx-auto">{content}</div>
                         </div>
                     </div>
                 </div>
             )}
         </div>
     );
 };

 const App = () => {
     const url = new URL(location.href);
     const urlId = url.searchParams.get("songid");

     // TODO back
     const [gameStage, setGameStage] = useState(
         urlId === null ? "start" : "popup"
     ); //start | popup | gameMap
     const [model, setModel] = useState(0); //0
     const [mark, setMark] = useState(1); //1
     const [openModel, setOpenModel] = useState(false); //false
     const [oneMvData, setOneMvData] = useState(null);

     const { screenWidth, screenHeight } = useScreenSize();
     const isMobile = screenWidth <= 500;

     const ref = useRef(null);
     const SCref = useRef(null);

     const [fbToken, setFbToken] = useState("");

     const setCookie = () => {
         if (location.href.includes("token=")) {
             const lHref = location.href.toString().split("token=");
             const lastID = lHref[lHref.length - 1].split("#_=_")[0];
             Cookies.set("2023GS_token", lastID, { expires: 14 });
             return lastID;
         }
     };

     const getCookie = () => {
         if (!Cookies.get("2023GS_token")) {
             setFbToken(setCookie());
         } else {
             if (Cookies.get("2023GS_token") === fbToken) return;
             setFbToken(Cookies.get("2023GS_token"));
         }
     };

     const onOpenIdUrl = () => {
         const localID = localStorage.getItem("songid");
         if (urlId === null) {
             return null;
         } else if (localID) {
             getOneMv(localID);
             setGameStage("gameMap");
             setModel(3);
             setMark(3);
             setOpenModel(true);
         } else if (urlId.length > 0) {
             getOneMv(urlId);
             setGameStage("gameMap");
             setModel(3);
             setMark(3);
             setOpenModel(true);
         }
     };

     useEffect(() => {
         onOpenIdUrl();
         setCookie();
     }, []);

     const getOneMv = async (id) => {
         try {
             const res = await axios({
                 url: routes.getmvlist + `/${id}`,
                 method: "get",
             });
             if (res.data.status === 200) {

                 setOneMvData(res.data.data);
             }
         } catch (err) {
             console.log(err);
         }
     };

     // set buildingVisited to localStorage
     const buildingInit = {
         a: false,
         b: false,
         c: false,
         d: false,
         e: false,
     };
     const [buildingVisited, setBuildingVisited] = useState(buildingInit);

     useEffect(() => {
         const storedValue = localStorage.getItem("buildingVisited");
         if (storedValue) {
             setBuildingVisited(JSON.parse(storedValue));
         }
     }, []);

     useEffect(() => {
         localStorage.setItem(
             "buildingVisited",
             JSON.stringify(buildingVisited)
         );
     }, [buildingVisited]);

     // -------- map move ----------
     const [containerState, setContainerState] = useState({
         isDown: false,
         startX: 0,
         startY: 0,
         scrollLeft: 0,
         scrollTop: 0,
     });
     const screen = screenWidth <= 500 ? "md" : "lg";

     const { isDown, startX, startY, scrollLeft, scrollTop } = containerState;
     const [isMoving, setIsMoving] = useState(false);
     const [pathState, setPathState] = useState({
         reverse: false,
         toMark: 0,
     });
     const { reverse, toMark } = pathState;

     useEffect(() => {
         if (mark === toMark || toMark === 0) {
             setIsMoving(false);
         } else {
             setIsMoving(true);
         }
     }, [mark, toMark]);

     useEffect(() => {
         const gsap = window.gsap;
         const device = isMobile ? "mb" : "desktop";

         const pathMove = (mark) => {
             const pathMark = !reverse ? mark - 1 : mark;
             const start = gsap.set(SCref.current, {
                 x: isMobile ? 531.818 : 2064.648,
                 y: isMobile ? 353.545 : 261.91,
             });
             start;
             if (toMark === 0) return;
             const animation = gsap.to(SCref.current, {
                 duration: pathMoveData[device][pathMark || 1].duration,
                 rotation: 0,
                 start: 0,
                 motionPath: {
                     autoRotate: false,
                     path: pathMoveData[device][pathMark || 1].path,
                 },
                 onReverseComplete: () => {
                     if (mark === toMark) {
                         setOpenModel(true);
                     } else {
                         if (toMark === 0) {
                             setMark(1);
                         } else if (reverse) {
                             setMark((pre) => (pre === toMark ? pre : pre - 1));
                         } else if (!reverse) {
                             setMark((pre) => (pre === toMark ? pre : pre + 1));
                         }
                     }
                 },
                 onComplete: () => {
                     if (reverse) return;

                     if (mark === toMark) {
                         setOpenModel(true);
                     } else {
                         if (toMark === 0) {
                             setMark(1);
                         } else if (reverse) {
                             setMark((pre) => (pre === toMark ? pre : pre - 1));
                         } else if (!reverse) {
                             setMark((pre) => (pre === toMark ? pre : pre + 1));
                         }
                     }
                 },
             });

             if (reverse) {
                 animation.reverse(0);
             } else {
                 animation;
             }
         };

         pathMove(mark);
     }, [mark]);


     // 進場動畫、移動



     const atMousedown = (e) => {
         const x = e.pageX - ref.current.offsetLeft;
         const y = e.pageY - ref.current.offsetTop;
         setContainerState({
             isDown: true,
             startX: x,
             startY: y,
             scrollLeft: ref.current.scrollLeft,
             scrollTop: ref.current.scrollTop,
         });
     };

     const atMouseleave = () => {
         setContainerState({
             ...containerState,
             isDown: false,
         });
     };
     const atMouseup = () => {
         setContainerState({
             ...containerState,
             isDown: false,
         });
     };
     const atMousemove = (e) => {
         if (!isDown) return;

         e.preventDefault();

         let x = e.pageX - ref.current.offsetLeft;
         let y = e.pageY - ref.current.offsetTop;

         let walkX = (x - startX) * 1.5;
         let walkY = (y - startY) * 1.5;
         if (walkX * walkY === 0) return;

         ref.current.scrollTo({
             left: scrollLeft - walkX,
             top: scrollTop - walkY,
         });
     };

     // for mobile

     const atTouchStart = (e) => {
         const touch = e.touches[0]; // Retrieve the first touch point
         const pageX = touch.pageX; // Get the X coordinate of the touch
         const pageY = touch.pageY;
         const x = pageX - ref.current.offsetLeft;
         const y = pageY - ref.current.offsetTop;
         setContainerState({
             isDown: true,
             startX: x,
             startY: y,
             scrollLeft: ref.current.scrollLeft,
             scrollTop: ref.current.scrollTop,
         });
     };

     const atTouchEnd = () => {
         setContainerState({
             ...containerState,
             isDown: false,
         });
     };

     const atTouchMove = (e) => {
         if (!isDown) return;

         e.preventDefault();

         const touch = e.touches[0]; // Retrieve the first touch point
         const pageX = touch.pageX; // Get the X coordinate of the touch
         const pageY = touch.pageY;

         let x = pageX - ref.current.offsetLeft;
         let y = pageY - ref.current.offsetTop;

         let walkX = (x - startX) * 1.5;
         let walkY = (y - startY) * 1.5;
         if (walkX * walkY === 0) return;

         ref.current.scrollTo({
             left: scrollLeft - walkX,
             top: scrollTop - walkY,
         });
     };

     useEffect(() => {
         if (mark === 0) return;
         if (isMobile) {
             ref.current.scrollTo({
                 left: markPosition(isMobile)[mark].x,
                 top: markPosition(isMobile)[mark].y,
             });
         } else {
             ref.current.scrollTo({
                 left: markPosition(isMobile)[mark].x,
                 top: markPosition(isMobile)[mark].y,
                 behavior: "smooth",
             });
         }
     }, [mark]);
     var atPop = window.setTimeout(() => {
         // TODO bug 兩秒內按掉會跳回 popup

         if (gameStage === "start") {
             setGameStage("popup");
         }
     }, 2000);
     // 地圖位移設定
     useEffect(() => {
         if (gameStage === "start") {
             ref.current.scrollTo({
                 left: 0,
                 top: 0,
             });

             atPop;
             //  setInterval(() => {
             //        if (gameStage === "start") {
             //          setGameStage("popup");
             //         }
             //      }, 2000);
         } else if (gameStage === "popup") {
             // 到地圖起始點

             if (isMobile) {
                 ref.current.scrollTo({
                     left: markPosition(isMobile)[1].x,
                     top: markPosition(isMobile)[1].y,
                 });
             } else {
                 ref.current.scrollTo({
                     left: markPosition(isMobile)[1].x,
                     top: markPosition(isMobile)[1].y,
                     behavior: "smooth",
                 });
             }
         }
     }, [gameStage]);

     // -------- end of map setting -----------

     const markPosition = (isMobile) => {
         const mapWH = isMobile
             ? { sH: 1400, sW: 798 }
             : { sH: 1575, sW: 2800 };
         if (isMobile) {
             return {
                 1: {
                     x: mapWH.sW * 0.68 - screenWidth / 2,
                     y: mapWH.sH * 0.3 - screenHeight / 2,
                 },
                 2: {
                     x: mapWH.sW * 0.66 - screenWidth / 2,
                     y: mapWH.sH * 0.45 - screenHeight / 2,
                 },
                 3: {
                     x: mapWH.sW * 0.45 - screenWidth / 2,
                     y: mapWH.sH * 0.54 - screenHeight / 2,
                 },
                 4: {
                     x: mapWH.sW * 0.35 - screenWidth / 2,
                     y: mapWH.sH * 0.7 - screenHeight / 2,
                 },
                 5: {
                     x: mapWH.sW * 0.6 - screenWidth / 2,
                     y: mapWH.sH * 0.63 - screenHeight / 2,
                 },
                 6: {
                     x: mapWH.sW * 0.7 - screenWidth / 2,
                     y: mapWH.sH * 0.36 - screenHeight / 2,
                 },
             };
         } else {
             return {
                 1: {
                     x: mapWH.sW * 0.72 - screenWidth / 2,
                     y: mapWH.sH * 0.25 - screenHeight / 2,
                 },
                 2: {
                     x: mapWH.sW * 0.65 - screenWidth / 2,
                     y: mapWH.sH * 0.4 - screenHeight / 2,
                 },
                 3: {
                     x: mapWH.sW * 0.45 - screenWidth / 2,
                     y: mapWH.sH * 0.4 - screenHeight / 2,
                 },
                 4: {
                     x: mapWH.sW * 0.36 - screenWidth / 2,
                     y: mapWH.sH * 0.71 - screenHeight / 2,
                 },
                 5: {
                     x: mapWH.sW * 0.48 - screenWidth / 2,
                     y: mapWH.sH * 0.65 - screenHeight / 2,
                 },
                 6: {
                     x: mapWH.sW * 0.86 - screenWidth / 2,
                     y: mapWH.sH * 0.4 - screenHeight / 2,
                 },
             };
         }
     };

     useEffect(() => {
         if (toMark === 0) {
             setMark(1);
         } else if (reverse) {
             setMark((pre) => (pre === toMark ? pre : pre - 1));
         } else {
             setMark((pre) => (pre === toMark ? pre : pre + 1));
         }
     }, [pathState]);

     const handelRoadMark = (roadMark) => {
         if (gameStage !== "gameMap") {
             setGameStage("gameMap");
         }
         if (isMobile && roadMark.id === 3) {
             setOpenModel(true);
         }
         if (isMoving) return;
         setOpenModel(false);
         if (roadMark.id === 0) {
             setOpenModel(true);
         }
         if (mark === roadMark.id) {
             setTimeout(() => {
                 setOpenModel(true);
             }, 0);

             setPathState({
                 toMark: roadMark.id,
                 reverse: true,
             });
         } else if (mark > roadMark.id) {
             setPathState({
                 toMark: roadMark.id,
                 reverse: true,
             });
         } else {
             setPathState({
                 toMark: roadMark.id,
                 reverse: false,
             });
         }
         setModel(roadMark.id);
     };

     const roadMarks = markData.road.map((roadMark) => {
         if (roadMark.id === 0) return;
         return (
             <button
                 className="map-mark"
                 data-num={roadMark.id}
                 onClick={() => handelRoadMark(roadMark)}
             />
         );
     });
     const buildingMarks = markData.building.map((buildingMark) => (
         <>
             <button
                 className="building-mark"
                 data-id={buildingMark.id}
                 onClick={() => {
                     if (isMoving) return;
                     setOpenModel(true);
                     setModel(buildingMark.id);
                     setBuildingVisited({
                         ...buildingVisited,
                         [buildingMark.id]: true,
                     });
                 }}
             />
         </>
     ));

     return (
         <div
             id="app"
             ref={ref}
             className={`w-[${screenWidth}px] h-[${screenHeight}px]`}
         >
             {gameStage === "popup" && (
                 <div
                     className="darken-bg z-50"
                     id="popup-list"
                     onClick={() => {
                         setGameStage("gameMap");
                         window.clearTimeout(atPop);
                     }}
                     data-stage={gameStage}
                 >
                     <div className="z-40 mb-[80px] p-2 mx-6 flex items-center justify-center top-0 right-0 left-0 mx-auto md:my-auto rounded-lg relative md:z-50 z-60 h-[80%] w-[95%] md:h-[95%] md:w-auto">
                         <img
                             src="/gs2023/images/scooter.png"
                             alt=""
                             className="absolute right-[-100px] bottom-0 z-40 w-[170px] md:block hidden h-[170px]"
                         />
                         <div className="road-border flex flex-col gap-6 ">
                             <div className="overflow-y-auto overflow-x-hidden md:mx-auto h-full w-full ">
                                 <button
                                     className="close-btn"
                                     onClick={() => setOpenModel(false)}
                                 ></button>

                                 <div
                                     onClick={(e) => e.stopPropagation()}
                                     className="mx-auto mx-10 my-8 whitespace-pre-line "
                                 >
                                     <p>
                                         {`感謝大家熱情參與本次2023逗陣來SONG！達人秀x勁戰畢業歌大賽
                                     以下將公佈熱騰騰的得獎名單出來囉～恭喜恭喜！`}
                                     </p>
                                     <h2 className="text-2xl pt-10 pb-3 font-bold">
                                         【畢業歌曲得獎隊伍】
                                     </h2>
                                     <p>
                                         {`第一名：屏榮高中｜一雙手
                                     第二名：新民高中｜We
                                     第三名：屏東大學｜三桿廣場
                                     超夯人氣獎：屏榮高中｜一雙手
                                     YAMAHA贊助獎：實踐大學｜去哪裡都想和你一起`}
                                     </p>
                                     <hr className="my-10" />

                                     <h2 className="text-2xl pb-3 font-bold">
                                         【串流平台上架名單】
                                     </h2>
                                     <p className="font-normal">
                                         {`以下歌曲皆可獲得由達人秀上架至串流平台(Spotify & KKBOX)`}
                                     </p>
                                     <p>
                                         {`
                                         屏榮高中｜一雙手
新民高中｜We
屏東大學｜三桿廣場
大同國小｜山的孩子
台東大學｜《東·日》
香港浸會大學｜再見再不見
西螺農工｜星憶
輔仁中學｜我想回到
青年高中｜離巢
蘭陽女中｜75%青春微甜
實踐大學｜去哪裡都想和你一起`}
                                     </p>
                                     <hr className="my-10" />

                                     <h2 className="text-2xl pb-3 font-bold">
                                         【城市尋寶抽獎名單】
                                     </h2>
                                     <p>
                                         {`Girls store｜小被被布丁午餐袋*1
1. 龔O毅 0958-XXX-806
2. 蘇O堂 0912-XXX-023
3. 李O紜 0903-XXX-252

Girls store｜懶惰草莓午餐袋*1
1. 何O懌 0906-XXX-849
2. 尤O玟 0963-XXX-928
3. 李O喨 0981-XXX-599

REDOU｜美國47獨家訂製老帽(chill chill chill款)*1
1. 羅O洺 0988-XXX-451
2. 楊O君 0976-XXX-042
3. 程O雲 0937-XXX-163
4. 陳O廷 0968-XXX-725
5. 許O鈴 0986-XXX-230

REDOU｜防疫重磅潮Ｔ(款式/尺寸隨機出貨)
1. 吳O萱 0976-XXX-200
2. 湯O潔 0966-XXX-368
3. 羅O倫 0933-XXX-015
4. 方O彬 0966-XXX-475
5. 范O鳴 0989-XXX-555

Infothink｜安琪寶貝蛋藍牙耳機
1. 李O佩 0918-XXX-846
2. 劉O倫 0930-XXX-946

Infothink｜史迪奇寶貝蛋藍牙耳機
1. 陳O益 0933-XXX-185
2. 馬O英 0919-XXX-844

Soundcore Mini 3 Pro｜藍牙喇叭
1. 張O盈 0966-XXX-058
2. 江O恩 0975-XXX-737
3. 黃O博 0911-XXX-720
`}
                                         <hr className="my-10" />
                                     </p>
                                     <p className="font-semibold">
                                         {`活動官方將於3個工作日內以信件或電話聯繫上述「歌曲得獎隊伍」&「城市尋寶中獎者」，若滿三次仍未聯繫成功，將視同放棄資格。`}
                                         <br />
                                         並請於8/11前，「下載」並完成填寫
                                         <a
                                             className="text-[#00A1E7] underline"
                                             target="_blank"
                                             href="https://docs.google.com/document/d/1vvGd9dSIycCE022aof7BvnuMA02Tolwy/edit?usp=drive_link&ouid=108504725770982936796&rtpof=true&sd=true"
                                         >
                                             「中獎領獎單」
                                         </a>
                                         ，回寄至irischen@supermedia.cool，經核對個人資料無誤後，將安排相關獎品/項寄送。
                                         <br />
                                         <p className="mt-4">
                                             {`聯繫信箱：irischen@supermedia.cool
                                         聯繫電話：(02)7709-5168 #617`}
                                         </p>
                                     </p>
                                 </div>
                             </div>
                         </div>
                     </div>
                 </div>
             )}

             {openModel && (
                 <Model
                     setOpenModel={setOpenModel}
                     model={model}
                     setBuildingVisited={setBuildingVisited}
                     buildingVisited={buildingVisited}
                     buildingInit={buildingInit}
                     oneMvData={oneMvData}
                     setOneMvData={setOneMvData}
                     onOpenIdUrl={onOpenIdUrl}
                     // onLogin={onLogin}
                     setFbToken={setFbToken}
                     getCookie={getCookie}
                     setCookie={setCookie}
                     fbToken={fbToken}
                     getOneMv={getOneMv}
                 />
             )}

             {gameStage === "start" && (
                 <div
                     className="darken-bg fade-animate-in"
                     onClick={() => setGameStage("popup")}
                 >
                     <img
                         src="/gs2023/images/main-logo.png"
                         alt=""
                         className="max-w-[700px] p-4 md:p-0"
                     />
                 </div>
             )}

             <section
                 id="game-map"
                 className={`relative ${isDown ? "active" : ""}`}
                 data-stage={gameStage}
                 onMouseDown={(e) => atMousedown(e)}
                 onMouseUp={atMouseup}
                 onMouseLeave={atMouseleave}
                 onMouseMove={(e) => atMousemove(e)}
                 onTouchStart={(e) => atTouchStart(e)}
                 onTouchEnd={atTouchEnd}
                 onTouchCancel={atTouchEnd}
                 onTouchMove={(e) => atTouchMove(e)}
             >
                 {/* bg-items */}
                 <div
                     className="bg-items data-[show=start]:hidden"
                     data-show={gameStage}
                     data-screen={screen}
                 >
                     <img
                         src="/gs2023/images/scooter.png"
                         id="scooter"
                         className="no-select"
                         ref={SCref}
                         alt=""
                     />

                     <div className="static-building no-select" />
                     {buildingMarks}
                     {roadMarks}
                     {/* static items */}
                     <button
                         className="tt-character"
                         onClick={() => {
                             if (isMoving) return;
                             window.open("https://www.ttshow.tw/", "_blank");
                         }}
                     ></button>
                     <div className="ship no-select"></div>
                     <div className="clouds-1 no-select"></div>
                     <div className="clouds-2 no-select"></div>
                     <div className="item no-select z-20 md:z-0"></div>
                     <div className="sparkle no-select "></div>
                 </div>
             </section>

             {/* top logo area */}
             <div className="fixed z-20 top-0 left-0 right-0 flex w-full flex-row-reverse justify-between md:p-6 pt-4 pr-6 pl-[1rem] no-select">
                 <img
                     src="/gs2023/images/yamaha-logo.png"
                     className="md:w-[200px] w-[140px] z-20 h-full"
                     alt=""
                 />
                 <img
                     src="/gs2023/images/main-logo.png"
                     className="data-[show=start]:hidden no-select md:w-[250px] w-[140px]"
                     data-show={gameStage}
                     alt=""
                 />
             </div>

             <div
                 id="step-bar"
                 className="mx-auto rounded-t-xl data-[show=start]:hidden"
                 data-show={gameStage}
                 data-top={gameStage !== "popup"}
             >
                 <div
                     className="skip-btn no-select fixed md:bottom-[200px] md:right-[100px] right-[30px] bottom-[110px] border-white border-2 border rounded-full px-4 py-2 text-white cursor-pointer"
                     data-active={gameStage === "popup"}
                 >
                     skip
                 </div>
                 <div className="road">
                     {markData.road.map((item) => (
                         <div
                             className="bar-item"
                             key={item.id}
                             onClick={() => {
                                 handelRoadMark(item);
                             }}
                         >
                             <img
                                 className="bar-mark animate-bounce"
                                 src="/gs2023/images/bar-mark.png"
                                 alt=""
                                 // data-show={gameStage}
                                 data-active={
                                     item.id === mark && gameStage !== "popup"
                                 }
                                 onClick={(e) => {
                                     if (gameStage === "popup") {
                                         e.stopPropagation();
                                     }
                                 }}
                             />

                             <img
                                 src={`/gs2023/images/bar-${item.id}.png`}
                                 className="bar-num mx-auto px-1 md:px-0"
                             />
                             <img
                                 src={`/gs2023/images/bar-item-${item.id}.png`}
                                 className="bar-title"
                             />
                         </div>
                     ))}
                 </div>
             </div>
         </div>
     );
 };

const data_signUpCompetitions = (
    <>
        <meta httpEquiv="Content-Type" content="text/html; charset=UTF-8" />
        <meta httpEquiv="Content-Style-Type" content="text/css" />
        <meta name="generator" content="Aspose.Words for .NET 17.1.0.0" />
        <title />
        <div>
            <div style={{ AwSdtTag: '"goog_rdk_1"' }}>
                <p
                    style={{
                        textAlign: "center",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                        fontSize: "16pt",
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_0"' }}>
                        <span
                            style={{
                                fontFamily: "'Noto Sans TC', sans-serif",
                                fontWeight: "bold",
                                fontSize: "24px",
                                paddingTop: "10px",
                            }}
                        >
                            逗陣來Song！
                        </span>
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_3"' }}>
                <p
                    style={{
                        textAlign: "center",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                        fontSize: "24pt",
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_2"' }}>
                        <span
                            style={{
                                fontFamily: "'Noto Sans TC', sans-serif",
                                fontWeight: "bold",
                                fontSize: "24px",
                                paddingTop: "10px",
                            }}
                        >
                            2023達人秀x勁戰
                            <br />
                            勁音之王畢業歌大賽
                            <br />
                            活動辦法
                        </span>
                    </span>
                </p>
            </div>

            <div style={{ AwSdtTag: '"goog_rdk_7"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginBottom: "14pt",
                        textAlign: "center",
                        lineHeight: "182%",
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_6"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            &nbsp;
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_9"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginBottom: "14pt",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_8"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            一）活動期程：
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_13"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginLeft: "16pt",
                        marginBottom: "14pt",
                        textIndent: "-14pt",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_10"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            1.
                        </span>
                    </span>
                    <span style={{ paddingRight: "2px" }} />

                    <span style={{ AwSdtTag: '"goog_rdk_12"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            報名時間：即日起至西元 2023 年 7 月 7 日 23:59。
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_17"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginLeft: "16pt",
                        marginBottom: "14pt",
                        textIndent: "-14pt",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_14"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            2.
                        </span>
                    </span>
                    <span style={{ paddingRight: "2px" }} />

                    <span style={{ AwSdtTag: '"goog_rdk_16"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            投票期間： 2023 年 7 月 17 日 00:00 起至 7 月 28 日
                            23:59 進行投票
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_21"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginLeft: "16pt",
                        marginBottom: "14pt",
                        textIndent: "-14pt",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_18"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            3.
                        </span>
                    </span>
                    <span style={{ paddingRight: "2px" }} />

                    <span style={{ AwSdtTag: '"goog_rdk_20"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            得獎公告： 2023 年 8 月 4 日
                            中午12:00公布得獎名單並於日後聯繫得獎者領獎方式
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_23"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginBottom: "14pt",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_22"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            (依主辦單位系統時間為主逾期恕不受理；為避免最後投稿截止網路壅塞請盡早完成報名。)
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_25"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginLeft: "16pt",
                        marginBottom: "14pt",
                        textIndent: "-14pt",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_24"' }} />
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_27"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginBottom: "14pt",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_26"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            二）參賽者資格：
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_31"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginLeft: "16pt",
                        marginBottom: "14pt",
                        textIndent: "-14pt",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_28"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            1.
                        </span>
                    </span>
                    <span style={{ paddingRight: "2px" }} />

                    <span style={{ AwSdtTag: '"goog_rdk_30"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            凡18歲以上，均可報名
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_35"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginLeft: "16pt",
                        marginBottom: "14pt",
                        textIndent: "-14pt",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_32"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            2.
                        </span>
                    </span>
                    <span style={{ paddingRight: "2px" }} />

                    <span style={{ AwSdtTag: '"goog_rdk_34"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            可個人或2人以上團體報名，須一位(含)以上的團員符合18歲以上。
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_39"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginLeft: "16pt",
                        marginBottom: "14pt",
                        textIndent: "-14pt",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_36"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            3.
                        </span>
                    </span>
                    <span style={{ paddingRight: "2px" }} />

                    <span style={{ AwSdtTag: '"goog_rdk_38"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            報名後團員不得任意更換，如遇不可抗拒之因素，須經由主辦方同意。
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_41"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginBottom: "14pt",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_40"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            &nbsp;
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_43"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginBottom: "14pt",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_42"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            三）作品規格：
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_47"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginLeft: "16pt",
                        marginBottom: "14pt",
                        textIndent: "-14pt",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_44"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            1.
                        </span>
                    </span>
                    <span style={{ paddingRight: "2px" }} />

                    <span style={{ AwSdtTag: '"goog_rdk_46"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            作品長度建議以 3-5
                            分鐘為佳，且須經主辦方及評審認定屬完整之歌曲。
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_51"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginLeft: "16pt",
                        marginBottom: "14pt",
                        textIndent: "-14pt",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_48"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            2.
                        </span>
                    </span>
                    <span style={{ paddingRight: "2px" }} />

                    <span style={{ AwSdtTag: '"goog_rdk_50"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            作品須同時包含歌詞及樂曲旋律之創作，單以歌詞或單以樂曲旋律參賽皆不符合參賽資格。
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_55"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginLeft: "16pt",
                        marginBottom: "14pt",
                        textIndent: "-14pt",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_52"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            3.
                        </span>
                    </span>
                    <span style={{ paddingRight: "2px" }} />

                    <span style={{ AwSdtTag: '"goog_rdk_54"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            可以獨唱、重唱或合唱等形式呈現，演唱者不限參賽者本人。
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_59"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginLeft: "16pt",
                        marginBottom: "14pt",
                        textIndent: "-14pt",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_56"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            4.
                        </span>
                    </span>
                    <span style={{ paddingRight: "2px" }} />

                    <span style={{ AwSdtTag: '"goog_rdk_58"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            若有拍攝MV影片呈現歌曲故事及氛圍甚佳。
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_63"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginLeft: "16pt",
                        marginBottom: "14pt",
                        textIndent: "-14pt",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_60"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            5.
                        </span>
                    </span>
                    <span style={{ paddingRight: "2px" }} />

                    <span style={{ AwSdtTag: '"goog_rdk_62"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            作品上傳需為MP4規格，若無拍攝MV之隊伍可運用團隊圖片為背景製作成MP4格式。
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                    <p
                        style={{
                            marginTop: "14pt",
                            marginLeft: "16pt",
                            marginBottom: "14pt",
                            textIndent: "-14pt",
                            lineHeight: "182%",
                        }}
                    >
                        <a
                            target="_blank"
                            href="https://youtu.be/edhd3aZotjQ"
                            style={{
                                fontFamily: "'Noto Sans TC', sans-serif",
                                textDecoration: "underline",
                                color: "#1155cc",
                            }}
                        >
                            圖片製作成MP4格式參考
                        </a>
                    </p>
                </p>
            </div>

            <div style={{ AwSdtTag: '"goog_rdk_70"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginBottom: "14pt",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_69"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            &nbsp;
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_72"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginBottom: "14pt",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_71"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            四）活動流程
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_76"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginLeft: "16pt",
                        marginBottom: "14pt",
                        textIndent: "-14pt",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_73"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            1.
                        </span>
                    </span>
                    <span style={{ paddingRight: "2px" }} />

                    <span style={{ AwSdtTag: '"goog_rdk_75"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            詳讀活動辦法、同意相關規定後，點選『點我報名』進入表單。
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_80"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginLeft: "16pt",
                        marginBottom: "14pt",
                        textIndent: "-14pt",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_77"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            2.
                        </span>
                    </span>
                    <span style={{ paddingRight: "2px" }} />

                    <span style={{ AwSdtTag: '"goog_rdk_79"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            填寫活動報名表單，確認個人資料並確切填寫音樂作品雲端連結(務必開啟連結共用)
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_84"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginLeft: "16pt",
                        marginBottom: "14pt",
                        textIndent: "-14pt",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_81"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            3.
                        </span>
                    </span>
                    <span style={{ paddingRight: "2px" }} />

                    <span style={{ AwSdtTag: '"goog_rdk_83"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            三天內確認是否收到報名確認信件，若未收到請寄信至
                            irischen@supermedia.cool 詢問
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_86"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginLeft: "16pt",
                        marginBottom: "14pt",
                        textIndent: "-14pt",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_85"' }} />
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_88"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginBottom: "14pt",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_87"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            五）參賽作品上傳規則
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_90"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginLeft: "16pt",
                        marginBottom: "14pt",
                        textIndent: "-14pt",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_77"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            1.
                        </span>
                    </span>
                    <span style={{ paddingRight: "2px" }} />
                    <span style={{ AwSdtTag: '"goog_rdk_89"' }}>
                        <span
                            style={{
                                fontFamily: "'Noto Sans TC', sans-serif",
                            }}
                        >
                            上傳優先順序為，依照我方收到報名資料之順序依序於上傳公開日安排上傳。
                        </span>
                    </span>
                    <span style={{}}>&nbsp;</span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_92"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginLeft: "16pt",
                        marginBottom: "14pt",
                        textIndent: "-14pt",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_77"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            2.
                        </span>
                    </span>
                    <span style={{ paddingRight: "2px" }} />
                    <span style={{ AwSdtTag: '"goog_rdk_91"' }}>
                        <span
                            style={{
                                fontWeight: "bold",
                                fontFamily: "'Noto Sans TC', sans-serif",
                            }}
                        >
                            7/14-7/16為上傳公開日。
                        </span>
                    </span>
                    <span style={{ fontSize: "14pt" }}>&nbsp;</span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_94"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginLeft: "16pt",
                        marginBottom: "14pt",
                        textIndent: "-14pt",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_77"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            3.
                        </span>
                    </span>
                    <span style={{ paddingRight: "2px" }} />
                    <span style={{ AwSdtTag: '"goog_rdk_93"' }}>
                        <span
                            style={{
                                fontWeight: "bold",
                                fontFamily: "'Noto Sans TC', sans-serif",
                            }}
                        >
                            影片每30分鐘上傳5支影片，上傳時段由主辦單位規劃為主。
                        </span>
                    </span>
                    <span style={{ fontSize: "14pt" }}>&nbsp;</span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_97"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginBottom: "14pt",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_95"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            &nbsp;
                        </span>
                    </span>
                    <span style={{ AwSdtTag: '"goog_rdk_96"' }} />
                    <span
                        style={{
                            fontFamily: "'Noto Sans TC', sans-serif",
                            fontSize: "7pt",
                        }}
                    >
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_100"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginBottom: "14pt",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_98"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            六
                        </span>
                    </span>
                    <span style={{ AwSdtTag: '"goog_rdk_99"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            ）評審及評分
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_104"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginLeft: "16pt",
                        marginBottom: "14pt",
                        textIndent: "-14pt",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_101"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            1.
                        </span>
                    </span>
                    <span style={{ paddingRight: "2px" }} />
                    <span style={{ AwSdtTag: '"goog_rdk_103"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            本次活動將由主辦單位及專業評審團共同評分占比為50%+活動網站網友投票數占比為
                            50%。
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_108"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginLeft: "16pt",
                        marginBottom: "14pt",
                        textIndent: "-14pt",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_105"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            2.
                        </span>
                    </span>
                    <span style={{ paddingRight: "2px" }} />

                    <span style={{ AwSdtTag: '"goog_rdk_107"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            徵選活動前三名由主辦單位及評審團依各參賽作品之歌詞創意、歌曲創意、編曲創意、詮釋、演唱技巧、畫面完整度等加以評分。
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_112"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginLeft: "16pt",
                        marginBottom: "14pt",
                        textIndent: "-14pt",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_109"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            3.
                        </span>
                    </span>
                    <span style={{ paddingRight: "2px" }} />

                    <span style={{ AwSdtTag: '"goog_rdk_111"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            超夯人氣獎以最終於「台灣達人秀YT平台觀看數最高者」獲得超夯人氣獎。
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_116"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginLeft: "16pt",
                        marginBottom: "14pt",
                        textIndent: "-14pt",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_113"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            4.
                        </span>
                    </span>
                    <span style={{ paddingRight: "2px" }} />

                    <span style={{ AwSdtTag: '"goog_rdk_115"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            YAMAHA贊助獎將由YAMAHA選出一名，若創作中有加入勁戰或是將品牌文字融入創作，皆有機會獲得加分評選。
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_120"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginLeft: "16pt",
                        marginBottom: "14pt",
                        textIndent: "-14pt",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_117"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            5.
                        </span>
                    </span>
                    <span style={{ paddingRight: "2px" }} />

                    <span style={{ AwSdtTag: '"goog_rdk_119"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            主辦單位有權依實際收件情形隨時調整評審作業方式。
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_122"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginBottom: "14pt",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_121"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            &nbsp;
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_124"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginBottom: "14pt",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_123"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            七）獎項
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_126"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginBottom: "14pt",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_125"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            第一名：獎金 50,000 元
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_128"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginBottom: "14pt",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_127"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            第二名：獎金 30,000 元
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_130"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginBottom: "14pt",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_129"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            第三名：獎金 20,000 元
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_132"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginBottom: "14pt",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_131"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            超夯人氣獎一名：獎金 10,000 元
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_134"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginBottom: "14pt",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_133"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            YAMAHA 特別獎：獎金10,000元
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_136"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginBottom: "14pt",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_135"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            得獎作品皆可獲得達人秀影音新聞獨家全網平台曝光及社群宣傳！達人秀小編讓你紅！
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_138"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginBottom: "14pt",
                        textAlign: "justify",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_137"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            第一名還可以獲得達人秀文章專訪乙篇並曝光於全網平台！
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_141"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginBottom: "14pt",
                        textAlign: "justify",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_139"' }}>
                        <span
                            style={{
                                fontFamily: "'Noto Sans TC', sans-serif",
                            }}
                        >
                            活動票選前十名及上方得獎者，歌曲將有機會由達人秀上架至串流平台(Spotify
                            &amp; KKBOX)
                        </span>
                    </span>
                    <span style={{ AwSdtTag: '"goog_rdk_140"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            ！
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_143"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginBottom: "14pt",
                        textAlign: "justify",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_142"' }} />
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_145"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginBottom: "14pt",
                        textAlign: "justify",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_144"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            八）參賽作品資格
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_149"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginLeft: "16pt",
                        marginBottom: "14pt",
                        textIndent: "-14pt",
                        textAlign: "justify",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_146"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            1.
                        </span>
                    </span>
                    <span style={{ paddingRight: "2px" }} />
                    <span style={{ AwSdtTag: '"goog_rdk_148"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            參賽者須保證作品為本人原創，且絕無抄襲或任何侵害他人著作權或其他權利之情事，作品所包含之影音、圖文、素材等相關內容，亦均未有侵害第三人之智慧財產權或其他權利。
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_153"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginLeft: "16pt",
                        marginBottom: "14pt",
                        textIndent: "-14pt",
                        textAlign: "justify",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_150"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            2.
                        </span>
                    </span>
                    <span style={{ paddingRight: "2px" }} />

                    <span style={{ AwSdtTag: '"goog_rdk_152"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            作品不得有任何涉及惡意誹謗、人身攻擊及/或不雅等字眼或內容。
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_157"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginLeft: "16pt",
                        marginBottom: "14pt",
                        textIndent: "-14pt",
                        textAlign: "justify",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_154"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            3.
                        </span>
                    </span>
                    <span style={{ paddingRight: "2px" }} />

                    <span style={{ AwSdtTag: '"goog_rdk_156"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            主辦單位保有審核參加資格之權利，若經主辦單位及評審認定參賽作品未依本辦法/規範之規定進行投稿，該參賽作品視同不符合參賽資格，主辦單位不另行通知，參賽者不得異議。
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_161"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginLeft: "16pt",
                        marginBottom: "14pt",
                        textIndent: "-14pt",
                        textAlign: "justify",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_158"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            4.
                        </span>
                    </span>
                    <span style={{ paddingRight: "2px" }} />

                    <span style={{ AwSdtTag: '"goog_rdk_160"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            每組參賽者限提供一組作品參賽，不得重複投遞。倘主辦單位認定同一參賽者重複投遞，主辦單位僅留存最後一次投稿做為參賽作品。
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_165"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginLeft: "16pt",
                        marginBottom: "14pt",
                        textIndent: "-14pt",
                        textAlign: "justify",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_162"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            5.
                        </span>
                    </span>
                    <span style={{ paddingRight: "2px" }} />
                    <span style={{ AwSdtTag: '"goog_rdk_164"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            若主辦單位或評審於公告得獎名單前發現或認定參賽作品有違反上開任一規範，主辦單位有權立即取消該參賽作品之參賽資格。
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_169"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginLeft: "16pt",
                        marginBottom: "14pt",
                        textIndent: "-14pt",
                        textAlign: "justify",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_166"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            6.
                        </span>
                    </span>
                    <span style={{ paddingRight: "2px" }} />

                    <span style={{ AwSdtTag: '"goog_rdk_168"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            若主辦單位於公告得獎名單後發現或認定有違反上述規範，主辦單位除有權立即取消參賽作品之得獎資格、將得獎作品自Spotify及KKBOX串流平台下架外，並得追回獎金，參賽者並應自負一切法律責任，如參加者提供之作品侵害第三人權利，導致主辦單位遭第三人請求賠償或涉訟而受有損害者，參加者應賠償主辦
                            單位所受損害(包括但不限於律師費及其他第三人請求之損害賠償)。
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_171"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginLeft: "24pt",
                        marginBottom: "14pt",
                        textAlign: "justify",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_170"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            &nbsp;
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_173"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginBottom: "14pt",
                        textAlign: "justify",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_172"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            九) 串流平台資訊內容
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_177"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginLeft: "16pt",
                        marginBottom: "14pt",
                        textIndent: "-14pt",
                        textAlign: "justify",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_174"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            1.
                        </span>
                    </span>
                    <span style={{ paddingRight: "2px" }} />

                    <span style={{ AwSdtTag: '"goog_rdk_176"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            活動網頁獲票數前十名、超夯人氣獎一名、YAMAHA
                            特別獎一名，皆可獲得作品上傳串流平台之資格(若得獎者重疊名額恕不順延)。
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_181"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginLeft: "16pt",
                        marginBottom: "14pt",
                        textIndent: "-14pt",
                        textAlign: "justify",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_178"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            2.
                        </span>
                    </span>
                    <span style={{ paddingRight: "2px" }} />

                    <span style={{ AwSdtTag: '"goog_rdk_180"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            上述得獎者需於得獎公告日(8/4)起5個工作天內，提供主辦單位其必要資訊(音檔格式、歌手介紹等)。
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_185"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginLeft: "16pt",
                        marginBottom: "14pt",
                        textIndent: "-14pt",
                        textAlign: "justify",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_182"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            3.
                        </span>
                    </span>
                    <span style={{ paddingRight: "2px" }} />

                    <span style={{ AwSdtTag: '"goog_rdk_184"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            主辦單位將協助上述得獎者作品上架至Spotify及KKBOX串流平台。
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_187"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginLeft: "24pt",
                        marginBottom: "14pt",
                        textAlign: "justify",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_186"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            &nbsp;
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_191"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginBottom: "14pt",
                        textAlign: "justify",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_188"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            十）
                        </span>
                    </span>
                    <span style={{ AwSdtTag: '"goog_rdk_189"' }}></span>
                    <span style={{ AwSdtTag: '"goog_rdk_190"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            著作財產權
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_195"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginLeft: "16pt",
                        marginBottom: "14pt",
                        textIndent: "-14pt",
                        textAlign: "justify",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_192"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            1.
                        </span>
                    </span>
                    <span style={{ paddingRight: "2px" }} />

                    <span style={{ AwSdtTag: '"goog_rdk_194"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            主辦單位擁有所有報名者於本活動上傳之作品、影片、照片等相關內容之使用權、重製權、公開播送權、公開傳輸權。主辦單位並有權將報名者於本活動上傳之作品、影片、照片等相關內容進行行銷、宣傳用途。
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_199"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginLeft: "16pt",
                        marginBottom: "14pt",
                        textIndent: "-14pt",
                        textAlign: "justify",
                        lineHeight: "167%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_196"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            2.
                        </span>
                    </span>
                    <span style={{ paddingRight: "2px" }} />

                    <span style={{ AwSdtTag: '"goog_rdk_198"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            主辦單位有權將得獎者之作品（包含作品相關之歌曲、歌詞、影片、照片等）上架至Spotify及KKBOX串流平台。得獎者作品於串流平台上架之相關權利約定，包含但不限於上架、下架、終止、修改與串流平台間約定之權利內容，得獎者同意授權主辦單位處理。
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_203"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginLeft: "16pt",
                        marginBottom: "14pt",
                        textIndent: "-14pt",
                        textAlign: "justify",
                        lineHeight: "167%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_200"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            3.
                        </span>
                    </span>
                    <span style={{ paddingRight: "2px" }} />

                    <span style={{ AwSdtTag: '"goog_rdk_202"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            前述串流平台所得歸主辦單位納入本活動之使用。得獎者若有異議，主辦單位得不上架至前述串流平台。
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_205"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginBottom: "14pt",
                        textAlign: "justify",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_204"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            &nbsp;
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_207"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginBottom: "14pt",
                        textAlign: "justify",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_206"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            十一）活動注意事項
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_211"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginLeft: "16pt",
                        marginBottom: "14pt",
                        textIndent: "-14pt",
                        textAlign: "justify",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_208"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            1.
                        </span>
                    </span>
                    <span style={{ paddingRight: "2px" }} />

                    <span style={{ AwSdtTag: '"goog_rdk_210"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            參加者於參加本活動的同時，即同意接受本活動之活動辦法與注意事項之規範，如有違反者得取消其參加或得獎者資格。對於個人資料，僅做為本活動聯絡用，活動執行單位將盡保密之責，不做其他用途亦不會對外洩漏。
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_215"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginLeft: "16pt",
                        marginBottom: "14pt",
                        textIndent: "-14pt",
                        textAlign: "justify",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_212"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            2.
                        </span>
                    </span>
                    <span style={{ paddingRight: "2px" }} />

                    <span style={{ AwSdtTag: '"goog_rdk_214"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            依中華民國稅法規定，金額超過新台幣20,000元，依法中獎者須先行繳納10%稅金(稅額以市價計算)，並由主辦單位代收代繳，使得領取活動獎金。
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_215"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginLeft: "16pt",
                        marginBottom: "14pt",
                        textIndent: "-14pt",
                        textAlign: "justify",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_212"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            3.
                        </span>
                    </span>
                    <span style={{ paddingRight: "2px" }} />

                    <span style={{ AwSdtTag: '"goog_rdk_214"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            活動期間為維護比賽公平性，禁止網友發表不當言論內容、從事任何非法程式、假借不真實身分參加本活動，以及任何影響活動公平性或破壞本活動進行之規則，一旦經查證或告發，將取消其參加活動資格，並追究法律責任。
                        </span>
                    </span>
                    <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                        &nbsp;
                    </span>
                </p>
            </div>
            <div style={{ AwSdtTag: '"goog_rdk_219"' }}>
                <p
                    style={{
                        marginTop: "14pt",
                        marginLeft: "16pt",
                        marginBottom: "14pt",
                        textIndent: "-14pt",
                        textAlign: "justify",
                        lineHeight: "182%",
                        widows: 0,
                        orphans: 0,
                    }}
                >
                    <span style={{ AwSdtTag: '"goog_rdk_216"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            4.
                        </span>
                    </span>
                    <span style={{ paddingRight: "2px" }} />

                    <span style={{ AwSdtTag: '"goog_rdk_218"' }}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            主辦單位保留擴大、修改、取消、終止該活動以及更改活動截止日期的權利，參賽者及投票者不得對主辦單位主張任何權利。
                        </span>
                    </span>
                </p>
            </div>
        </div>
    </>
);

const data_drawing = (isMobile) => {
    const numStyle1 = {
        marginLeft: isMobile ? "12pt" : "14pt",
        textIndent: isMobile ? "-11pt" : "-14pt",
        lineHeight: isMobile ? "2rem" : "2.4rem",
        fontSize: isMobile ? "16px" : "20px",
    };
    const numStyle2 = {
        marginLeft: isMobile ? "12pt" : "14pt",
        textIndent: isMobile ? "-17pt" : "-24pt",
        lineHeight: isMobile ? "2rem" : "2.4rem",
        fontSize: isMobile ? "16px" : "20px",
    };
    return (
        <div style={{ lineHeight: "182%" }}>
            <p
                style={{
                    marginTop: "14pt",
                    marginLeft: "16pt",
                    marginBottom: "14pt",
                    textIndent: "-14pt",
                    lineHeight: isMobile ? "2rem" : "2.4rem",
                    fontSize: isMobile ? "16px" : "20px",
                }}
            >
                <span
                    style={{
                        fontFamily: "'Noto Sans TC', sans-serif",
                        fontWeight: "bold",
                    }}
                >
                    【抽獎辦法】
                </span>
            </p>
            <p
                style={{
                    marginLeft: "10pt",
                    lineHeight: isMobile ? "2rem" : "2.4rem",
                    fontSize: isMobile ? "16px" : "20px",
                }}
            >
                <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                    點擊完以上於地圖中的城市地標，並填寫抽獎資訊，即可獲得抽獎機會乙次，並獲得下方豐富獎項。
                </span>
            </p>
            <p
                style={{
                    marginLeft: "10pt",
                    lineHeight: isMobile ? "2rem" : "2.4rem",
                    fontSize: isMobile ? "16px" : "20px",
                }}
            >
                <span></span>
                <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                    ※每人不限參加次數，但僅有一次中獎機會。
                </span>
            </p>
            <p
                style={{
                    marginTop: "14pt",
                    marginLeft: "16pt",
                    marginBottom: "14pt",
                    textIndent: "-14pt",
                    lineHeight: isMobile ? "2rem" : "2.4rem",
                    fontSize: isMobile ? "16px" : "20px",
                }}
            >
                <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                    &nbsp;
                </span>
            </p>
            <p
                style={{
                    marginTop: "14pt",
                    marginLeft: "16pt",
                    marginBottom: "14pt",
                    textIndent: "-14pt",
                    lineHeight: isMobile ? "2rem" : "2.4rem",
                    fontSize: isMobile ? "16px" : "20px",
                }}
            >
                <span
                    style={{
                        fontFamily: "'Noto Sans TC', sans-serif",
                        fontWeight: "bold",
                    }}
                >
                    【豐富獎項】
                </span>
            </p>
            <ol style={{ margin: "0pt", paddingLeft: "0pt" }} type={1}>
                <li
                    style={{
                        marginLeft: "10pt",
                        fontFamily: "'Noto Sans TC', sans-serif",
                        lineHeight: isMobile ? "1.8rem" : "2.4rem",
                        fontSize: isMobile ? "14px" : "20px",
                    }}
                >
                    <span
                        style={{
                            fontFamily: "'Noto Sans TC', sans-serif",
                            fontWeight: "bold",
                        }}
                    >
                        Girls store｜
                        <br />
                        小被被布丁午餐袋*1，共3名。
                    </span>
                </li>
                <li
                    style={{
                        marginLeft: "10pt",
                        widows: 0,
                        orphans: 0,
                        marginTop: "10pt",

                        fontFamily: "'Noto Sans TC', sans-serif",
                        lineHeight: isMobile ? "1.8rem" : "2.4rem",

                        fontSize: isMobile ? "14px" : "20px",
                    }}
                >
                    <span
                        style={{
                            fontFamily: "'Noto Sans TC', sans-serif",
                            fontWeight: "bold",
                        }}
                    >
                        Girls store｜
                        <br />
                        懶惰草莓午餐袋*1，共3名。
                    </span>
                </li>
                <li
                    style={{
                        marginLeft: "10pt",
                        widows: 0,
                        orphans: 0,
                        marginTop: "10pt",

                        fontFamily: "'Noto Sans TC', sans-serif",
                        lineHeight: isMobile ? "1.8rem" : "2.4rem",

                        fontSize: isMobile ? "14px" : "20px",
                    }}
                >
                    <span
                        style={{
                            fontFamily: "'Noto Sans TC', sans-serif",
                            fontWeight: "bold",
                        }}
                    >
                        REDOU｜
                        <br />
                        美國47獨家訂製老帽*1
                        <br />
                        (chill chill chill款)，共5名。
                    </span>
                </li>
                <li
                    style={{
                        marginLeft: "10pt",
                        widows: 0,
                        orphans: 0,
                        marginTop: "10pt",

                        fontFamily: "'Noto Sans TC', sans-serif",
                        lineHeight: isMobile ? "1.8rem" : "2.4rem",

                        fontSize: isMobile ? "14px" : "20px",
                    }}
                >
                    <span
                        style={{
                            fontFamily: "'Noto Sans TC', sans-serif",
                            fontWeight: "bold",
                        }}
                    >
                        REDOU｜
                        <br />
                        防疫重磅潮Ｔ*1
                        <br />
                        (款式/尺寸隨機出貨)，共5名。
                    </span>
                </li>
                <li
                    style={{
                        marginLeft: "10pt",
                        widows: 0,
                        orphans: 0,
                        marginTop: "10pt",

                        fontFamily: "'Noto Sans TC', sans-serif",
                        lineHeight: isMobile ? "1.8rem" : "2.4rem",

                        fontSize: isMobile ? "14px" : "20px",
                    }}
                >
                    <span
                        style={{
                            fontFamily: "'Noto Sans TC', sans-serif",
                            fontWeight: "bold",
                        }}
                    >
                        Infothink｜
                        <br />
                        安琪寶貝蛋藍牙耳機*1，共2名。
                    </span>
                </li>
                <li
                    style={{
                        marginLeft: "10pt",
                        widows: 0,
                        orphans: 0,
                        marginTop: "10pt",

                        fontFamily: "'Noto Sans TC', sans-serif",
                        lineHeight: isMobile ? "1.8rem" : "2.4rem",

                        fontSize: isMobile ? "14px" : "20px",
                    }}
                >
                    <span
                        style={{
                            fontFamily: "'Noto Sans TC', sans-serif",
                            fontWeight: "bold",
                        }}
                    >
                        Infothink｜
                        <br />
                        史迪奇寶貝蛋藍牙耳機*1，共2名。
                    </span>
                </li>
                <li
                    style={{
                        marginLeft: "10pt",
                        widows: 0,
                        orphans: 0,
                        marginTop: "10pt",

                        fontFamily: "'Noto Sans TC', sans-serif",
                        lineHeight: isMobile ? "1.8rem" : "2.4rem",

                        fontSize: isMobile ? "14px" : "20px",
                    }}
                >
                    <span
                        style={{
                            fontFamily: "'Noto Sans TC', sans-serif",
                            fontWeight: "bold",
                        }}
                    >
                        Soundcore｜
                        <br />
                        Mini 3 Pro 藍牙喇叭*1
                        <br />
                        (顏色隨機出貨)，共3名。
                    </span>
                </li>
            </ol>
            <p
                style={{
                    marginTop: "0pt",
                    marginLeft: "36pt",
                    marginBottom: "0pt",
                    lineHeight: isMobile ? "1.8rem" : "2.4rem",

                    fontSize: isMobile ? "16px" : "20px",
                }}
            >
                <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                    &nbsp;
                </span>
            </p>
            <p
                style={{
                    marginTop: "14pt",
                    marginLeft: "16pt",
                    marginBottom: "14pt",
                    textIndent: "-14pt",
                    lineHeight: "182%",

                    fontSize: isMobile ? "16px" : "20px",
                }}
            >
                <span
                    style={{
                        fontFamily: "'Noto Sans TC', sans-serif",
                        fontWeight: "bold",
                    }}
                >
                    【活動期間】
                </span>
            </p>
            <p
                style={{
                    marginLeft: "10pt",
                    lineHeight: isMobile ? "2rem" : "2.4rem",
                    fontSize: isMobile ? "16px" : "20px",
                }}
            >
                <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                    2023/06/19-2023/07/28
                </span>
            </p>
            <p
                style={{
                    marginTop: "14pt",
                    marginLeft: "16pt",
                    marginBottom: "14pt",
                    textIndent: "-14pt",
                    lineHeight: isMobile ? "2rem" : "2.4rem",
                    fontSize: isMobile ? "16px" : "20px",
                }}
            >
                <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                    &nbsp;
                </span>
            </p>
            <p
                style={{
                    marginTop: "14pt",
                    marginLeft: "16pt",
                    marginBottom: "14pt",
                    textIndent: "-14pt",
                    lineHeight: isMobile ? "2rem" : "2.4rem",
                    fontSize: isMobile ? "16px" : "20px",
                }}
            >
                <span
                    style={{
                        fontFamily: "'Noto Sans TC', sans-serif",
                        fontWeight: "bold",
                    }}
                >
                    【公布時間】
                </span>
            </p>
            <p
                style={{
                    marginLeft: "10pt",
                    lineHeight: isMobile ? "2rem" : "2.4rem",
                    fontSize: isMobile ? "16px" : "20px",
                }}
            >
                <span style={{ fontFamily: "'Noto Sans TC', sans-serif" }}>
                    2023/08/04
                </span>
            </p>
            <p
                style={{
                    marginTop: "14pt",
                    marginBottom: "14pt",
                    textIndent: "-14pt",
                    lineHeight: isMobile ? "2rem" : "2.4rem",
                    fontSize: isMobile ? "16px" : "20px",
                }}
            >
                <br />

                <p
                    style={{
                        marginTop: "14pt",
                        marginLeft: "16pt",
                        marginBottom: "14pt",
                        textIndent: "-14pt",
                        lineHeight: isMobile ? "2rem" : "2.4rem",
                        fontSize: isMobile ? "16px" : "20px",
                    }}
                >
                    <span
                        style={{
                            fontFamily: "'Noto Sans TC', sans-serif",
                        }}
                    >
                        【抽獎活動辦法】
                    </span>
                </p>

                <p style={numStyle1}>
                    <p style={numStyle1}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            1.
                        </span>
                        <span style={{ paddingRight: "2px" }} />
                        <span
                            style={{
                                fontFamily: "'Noto Sans TC', sans-serif",
                            }}
                        >
                            本活動由超人氣新媒體股份有限公司主辦。參加者於參加本活動之同時，即同意接受本活動注意事項、本網站使用規範及其他有關規定；若有違反，主辦單位得取消其參加資格，如為得獎者，則取消得獎資格。
                        </span>
                    </p>
                </p>

                <br />

                <p style={numStyle1}>
                    <p style={numStyle1}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            2.
                        </span>
                        <span style={{ paddingRight: "2px" }} />
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            獎品寄送地區僅限為台灣、金門、澎湖、馬祖地區，恕不郵寄獎項至海外地區。
                        </span>
                    </p>
                </p>
                <br />

                <p style={numStyle1}>
                    <p style={numStyle1}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            3.
                        </span>
                        <span style={{ paddingRight: "2px" }} />
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            若中獎人之贈品價值超過新台幣一千元，則中獎人需於收到中獎通知10日內，填寫完成主辦單位提供之中獎通知單，並寄回『台北市松山區復興北路337號12樓』進行確認。經確認無誤後方才符合領獎資格。若內容經主辦單位審核未通過、逾期或資料缺漏者，主辦單位亦不再進行通知。若通知信經招領逾期或不明原因等退回者，視同放棄且喪失中獎資格，主辦單位亦不再進行通知。
                        </span>
                    </p>
                </p>
                <br />

                <p style={numStyle1}>
                    <p style={numStyle1}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            4.
                        </span>
                        <span style={{ paddingRight: "2px" }} />
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            活動中獎者請務必詳細填寫正確資料，若資料有誤或不完整導致無法通知中獎人，將視同放棄得獎資格，恕不得要求主辦單位進行補發。
                        </span>
                    </p>
                </p>
                <br />

                <p style={numStyle1}>
                    <p style={numStyle1}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            5.
                        </span>
                        <span style={{ paddingRight: "2px" }} />
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            中獎人因資格不符或自行放棄中獎資格者，不另行網路公告，主辦單位並不再通知，亦不遞補。
                        </span>
                    </p>
                </p>
                <br />

                <p style={numStyle1}>
                    <p style={numStyle1}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            6.
                        </span>
                        <span style={{ paddingRight: "2px" }} />
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            寄送贈品過程中，如遇損壞、錯遞、延遲或遺失，若非可歸責於主辦單位者，主辦單位將恕不進行補發及遞補。
                        </span>
                    </p>
                </p>
                <br />

                <p style={numStyle1}>
                    <p style={numStyle1}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            7.
                        </span>
                        <span style={{ paddingRight: "2px" }} />
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            中獎之獎項如有其他規費、費用負擔時，包含但不限於過戶規費、手續費、保險費均由中獎者負擔。如中獎者不願繳納或未於主辦單位規定期限內繳納時，視同放棄，並不得要求兌換等值其他獎品及現金。如有放棄者主辦單位將不另進行缺額遞補。
                        </span>
                    </p>
                </p>
                <br />

                <p style={numStyle1}>
                    <p style={numStyle1}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            8.
                        </span>
                        <span style={{ paddingRight: "2px" }} />
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            本活動獎品獎項以實品為準，主辦單位將保留及更換其他等值獎品的相關權利，所有獎項皆無法兌換現金、轉讓或更換其他商品，主辦單位對獎品日後之使用及維修不負任何責任。
                        </span>
                    </p>
                </p>
                <br />

                <p style={numStyle1}>
                    <p style={numStyle1}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            9.
                        </span>
                        <span style={{ paddingRight: "2px" }} />
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            若經主辦單位發現惡意破壞或以非法方式網路破壞抽獎程式而中獎將視同無效，將直接取消抽獎資格，本公司恕不另行通知，亦不退件。
                        </span>
                    </p>
                </p>
                <br />

                <p style={numStyle1}>
                    <p style={numStyle2}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            10.
                        </span>
                        <span style={{ paddingRight: "2px" }} />
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            參加者聲明並承諾所有登錄、填寫或提出之資料均為真實且正確，且未冒用或盜用任何第三人之資料；若有冒用或盜用他人資料，或個人登錄資料有不實、不齊全或不正確之情事，主辦單位將取消參加或得獎資格。如因此致無法通知其得獎訊息時，主辦單位將不負任何責任。
                        </span>
                    </p>
                </p>
                <br />

                <p style={numStyle1}>
                    <p style={numStyle2}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            11.
                        </span>
                        <span style={{ paddingRight: "2px" }} />
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            主辦單位保有審核參加者之權利，及取消、終止、修改或暫停本活動辦法及獎品更動的權利。若有其他未盡事宜，悉依主辦單位相關規定或決定辦理。
                            若經主辦單位發現惡意大量登錄，並經主辦單位確認，將直接取消抽獎及兌獎資格，本公司恕不另行通知，如有造成對本公司損失之行為主辦單位保有法律追訴權。
                        </span>
                    </p>
                </p>
                <br />

                <p style={numStyle1}>
                    <p style={numStyle2}>
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            12.
                        </span>
                        <span style={{ paddingRight: "2px" }} />
                        <span
                            style={{ fontFamily: "'Noto Sans TC', sans-serif" }}
                        >
                            以上事項欲參加者應詳細閱讀，一經參加後，即視同參加者接受上述事項之約束，不得異議。
                        </span>
                    </p>
                </p>
            </p>
        </div>
    );
};

ReactDOM.render(<App />, document.querySelector("#root"));
